# -*- coding: utf-8 -*-
"""
Created on Mon Sep  9 10:14:03 2019

@author: 10167232
"""

import __main__ as _main_module
import h5py




from .__Config import type_level
from .__Config import path
from .__method import add_path
from .__method import get_path
type_list = type_level[0]

def to_HDF5(name = '',path = path):

    n = 0
    if name == '':
        path = add_path(path,'h5')
        if path == -1:
            return -1
    else:
        path = name



    try:
        HDF = h5py.File(path,mode = 'a')
        for i in _main_module.__dict__.copy().items():
            if str(type(i[1])).split("'")[1] in type_list and i[0][0] != '_':
                #print(i[0])
                HDF.create_dataset(i[0],data= i[1])
                n+=1
                #print(i[0])
        HDF.close()
        print(path)
        print("共保存了{}个元素".format(str(n)))
    except:
        print("io出错")
def from_HDF5(name = '',replace = False,path = path):

    
    
    n = 0
    if name == '':
        path = get_path(path,'h5')
        if path == -1:
            return -1
    else:
        path = name
    try:
        print('loading:'+path)
        HDF = h5py.File(path,mode = 'r')
        for i in HDF.keys():
            if hasattr(_main_module,i) and replace == False or str(type(HDF[i][()])).split("'")[1] not in type_list:
                pass
            else:
                print(i[0])
                setattr(_main_module,i,HDF[i][()])
                n+=1
        HDF.close()
        print("共读取了{}个元素".format(str(n)))
    except:
        print('io出错')


"""
建议使用HDF5格式
to_HDF5:变量保存为HDF5格式
from_HDF:从HDF5格式读取变量
dumps:保存内存中的变量
loads:读取已保存的变量到主命名空间（顺便引入numpy、pandas）
var_view:查看命名空间中的变量
clear_var:清除变量


Created on Thu Sep  5 14:11:55 2019

@author: karond
"""

__version__ = "0.3.5"
__author__ = 'karond'


from .__vars_pickle import dumps
from .__vars_pickle import loads
from .__vars_manga import var_view
from .__vars_manga import clear_var
from .__HDF5 import to_HDF5
from .__HDF5 import from_HDF5


import __main__ as _main_module
from .__Config import type_level



def var_view(level = 0):
    """
    显示变量空间中的变量
    """
    n=0
    if level>=0 and level< len(type_level):
        type_list = type_level[level]
        for i in _main_module.__dict__.copy().items():
            if i[0][0] != '_' and str(type(i[1])).split("'")[1] in type_list:
                print('name:{}    type:{}'.format(i[0],str(type(i[1])).split("'")[1]))
                n+=1
            else:
                pass
        print('共有{}个变量'.format(str(n)))
    else:
        return -1






def clear_var(save = [],level = 0):
    """
    清理变量空间
    """
    n = 0
    if level>=0 and level< len(type_level):
        type_list = type_level[level]
        for i in _main_module.__dict__.copy().items():
            if i[0][0] != '_' and i[0] not in save and str(type(i[1])).split("'")[1] in type_list:
                delattr(_main_module,i[0])
                n+=1
            else:
                pass
        print('删除{}个变量'.format(str(n)))
    else:
        return -1